<template>
  <a-card :bordered='false'>
    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='searchQuery'>
        <a-row :gutter='24'>
          <a-col :md='8' :sm='8'>
            <a-form-item label='时间区间'>
              <a-range-picker
                v-model='queryParam.dateRange'
                format='YYYY-MM-DD'
                :placeholder="['开始时间', '结束时间']"
                @change='onDateChange'>
              </a-range-picker>
            </a-form-item>
          </a-col>
          <a-col :md='8' :sm='8'>
            <a-form-item label='仪器名称' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>

              <a-select placeholder='请选择仪器名称' v-model='queryParam.instrumentId'>
                <a-select-option v-for='(item,index) in equList' :key='index' :value='item.id'>
                  {{ item.name }}
                </a-select-option>
              </a-select>

            </a-form-item>
          </a-col>

          <a-col :md='8' :sm='8'>
            <a-form-item label='点检人' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>
              <a-select placeholder='请选择点检人' v-model='queryParam.createBy'>
                <a-select-option v-for='(item,index) in userList' :key='index' :value='item.username'>
                  {{ item.realname }}
                </a-select-option>
              </a-select>
            </a-form-item>
          </a-col>
          <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
            <a-col :md='8' :sm='24'>
              <a-button type='primary' @click='searchQuery'>查询</a-button>
              <a-button style='margin-left: 8px' @click='searchReset'>重置</a-button>
            </a-col>
          </span>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button type='primary' icon='download' @click="handleExportXls('点检记录')">导出</a-button>
      <a-upload name='file' :showUploadList='false' :multiple='false' :headers='tokenHeader' :action='importExcelUrl'
                @change='handleImportExcel'>
        <a-button type='primary' icon='import'>导入</a-button>
      </a-upload>
      <!-- 高级查询区域 -->
      <j-super-query :fieldList='superFieldList' ref='superQueryModal'
                     @handleSuperQuery='handleSuperQuery'></j-super-query>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        :scroll='{x:true}'
        bordered
        rowKey='id'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        class='j-table-force-nowrap'
        @change='handleTableChange'>

        <span slot="spot" slot-scope="t, r">
          <template  v-for='i in t'  >
           <a-tag v-if='i.result==1' :key='i.id'  :color="'green'" >
           {{ i.itemName}}
           </a-tag>
             <a-tag v-else :key='i.id'  :color="'red'" >
           {{ i.itemName}}
           </a-tag>
          </template>

        </span>

        <template slot='htmlSlot' slot-scope='text'>
          <div v-html='text'></div>
        </template>
        <template slot='imgSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无图片</span>
          <img v-else :src='getImgView(text)' height='25px' alt=''
               style='max-width:80px;font-size: 12px;font-style: italic;' />
        </template>
        <template slot='fileSlot' slot-scope='text'>
          <span v-if='!text' style='font-size: 12px;font-style: italic;'>无文件</span>
          <a-button
            v-else
            :ghost='true'
            type='primary'
            icon='download'
            size='small'
            @click='downloadFile(text)'>
            下载
          </a-button>
        </template>

        <span slot='action' slot-scope='text, record'>
          <a @click='handleEdit(record)'>编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a @click='handleDetail(record)'>详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <lims-inspection-modal ref='modalForm' @ok='modalFormOk'></lims-inspection-modal>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LimsInspectionModal from './modules/LimsInspectionModal'
import { getAction } from '@api/manage'

export default {
  name: 'LimsInspectionList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    LimsInspectionModal
  },
  data() {
    return {
      description: '点检记录管理页面',
      userList: [],
      equList: [],
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '仪器',
          align: 'center',
          dataIndex: 'instrument'
        },
        {
          title: '点检项',
          align: 'center',
          dataIndex: 'items',
          scopedSlots: { customRender: 'spot' }},
        {
          title: '点检人',
          align: 'center',
          dataIndex: 'realname'
        },
        {
          title: '点检时间',
          align: 'center',
          dataIndex: 'inspectionTime',
          customRender: function(text) {
            return !text ? '' : (text.length > 10 ? text.substr(0, 10) : text)
          }
        },

        {
          title: '点检结果',
          align: 'center',
          dataIndex: 'result',
          customRender: function (t, r, index) {
            return  t == 1? '正常' : '异常'
          }
        },
       /* {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }*/
      ],
      url: {
        list: '/limsInspection/list',
        delete: '/limsInspection/delete',
        deleteBatch: '/limsInspection/deleteBatch',
        exportXlsUrl: '/limsInspection/exportXls',
        importExcelUrl: 'lims/limsInspection/importExcel',
        user: '/sys/user/list'

      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
    this.queryUserList()
    this.queryEquList()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'instrumentId', text: '仪器id', dictCode: '' })
      fieldList.push({ type: 'date', value: 'inspectionTime', text: '点检时间' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注', dictCode: '' })
      this.superFieldList = fieldList
    },
    onDateChange: function(value, dateString) {
      this.queryParam.createTime_begin = dateString[0]
      this.queryParam.createTime_end = dateString[1]
      this.$forceUpdate()
    },
    //查询设备列表
    queryEquList() {
      getAction('/limsInstrument/list').then(res => {
        if (res.success) {
          this.equList = res.result.records
        }

      })
    },
    queryUserList() {
      let params = {}
      params.pageNo = 1
      params.pageSize = 1000
      params.mini = 1   //只查询小程序人员
      getAction(this.url.user, params).then((res) => {
        console.info(res)
        if (res.success) {
          this.userList = res.result.records

        }
      })
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>